==> haskell-hs-bibutils-5.5-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hs-bibutils
version: 5.5
id: hs-bibutils-5.5-Bujn9fwi74P5NCilKdJf4S
key: hs-bibutils-5.5-Bujn9fwi74P5NCilKdJf4S
license: GPL
maintainer: andrea.rossato@unitn.it
homepage: http://istitutocolli.org/repos/hs-bibutils/
synopsis: Haskell bindings to bibutils, the bibliography
          conversion utilities.
description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.
    .
    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.
    .
    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.
    .
    The original API documentation is available here:
    <http://www.scripps.edu/~cdputnam/software/bibutils/library_specs.html>.
    .
    The package release number refers to the release number of
    the included bibutils library.
category: Text
author: Andrea Rossato
exposed: True
exposed-modules:
    Text.Bibutils
abi: 66d09c419d21ec3fca2580d4bc466406
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hs-bibutils-5.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/hs-bibutils-5.5
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/hs-bibutils-5.5
hs-libraries: HShs-bibutils-5.5-Bujn9fwi74P5NCilKdJf4S
includes:
    bibutils.h
depends:
    base-4.9.0.0 syb-0.6-C65vWCsht6A8uLstpQIXyj
haddock-interfaces: /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html: /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hs-bibutils-5.5-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hs-bibutils
version: 5.5
id: hs-bibutils-5.5-4dOwRxbGfcVH8ljpGkHYZY
key: hs-bibutils-5.5-4dOwRxbGfcVH8ljpGkHYZY
license: GPL
maintainer: andrea.rossato@unitn.it
homepage: http://istitutocolli.org/repos/hs-bibutils/
synopsis: Haskell bindings to bibutils, the bibliography
          conversion utilities.
description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.
    .
    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.
    .
    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.
    .
    The original API documentation is available here:
    <http://www.scripps.edu/~cdputnam/software/bibutils/library_specs.html>.
    .
    The package release number refers to the release number of
    the included bibutils library.
category: Text
author: Andrea Rossato
exposed: True
exposed-modules:
    Text.Bibutils
abi: 8b960c66f1290315f7b42077a095cf72
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hs-bibutils-5.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/hs-bibutils-5.5
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/hs-bibutils-5.5
hs-libraries: HShs-bibutils-5.5-4dOwRxbGfcVH8ljpGkHYZY
includes:
    bibutils.h
depends:
    base-4.9.1.0 syb-0.6-IcoSwlPi2Nx4zSqMmorFPS
haddock-interfaces: /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html: /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
